TableHeaderModel class

Constructors

TableHeaderModel({required String title, List<String>? subHeaders, double? width})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasSubHeaders bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subHeaders List<String>?
getter/setter pair
title String
getter/setter pair
totalWidth double?
no setter
width double?
getter/setter pair

Methods

getSubHeader() List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited